@@ -22,6 +22,7 @@ import email.utils
 import unforward.emailclients
 import quopri
 from unforward.errors import NoForwardFoundError
+from pprint import pprint
 
 class Extractor:
     """ This is the main class which handles extracting the original email from a chain of forwarded emails."""
@@ -42,15 +43,21 @@ class Extractor:
             a dictionary. """
         
         parsed_email = self.parser.parsestr(email_text)
-        payloads = parsed_email.get_payload()
-        if isinstance(payloads, list):
-            for payload in payloads:
-                if payload.get('content-type').startswith('text/html'):
-                    payload_string = quopri.decodestring(payload.get_payload())
-                    return self.extract_from_html(payload_string)
-        else:
-            payload_string = quopri.decodestring(payloads)
-            return self.extract_from_html(payload_string)
+        
+        def process_payload(payloads):
+            if isinstance(payloads, list):
+                for payload in payloads:
+                    if payload.get('content-type').startswith('text/html'):
+                        payload_string = quopri.decodestring(payload.get_payload())
+                        return self.extract_from_html(payload_string)
+                    elif payload.get('content-type').startswith('multipart/alternative'):
+                        return process_payload(payload.get_payload())
+                raise NotImplementedError("Did not find any payloads with text/html.")
+            else:
+                payload_string = quopri.decodestring(payloads)
+                return self.extract_from_html(payload_string)
+        
+        return process_payload(parsed_email.get_payload())
         
         
         
